@@ -1,21 +1,19 @@
 package Apache::Clean;
 
-use 5.008;
-
-use Apache2::Filter ();      # $f
-use Apache2::RequestRec ();  # $r
-use Apache2::RequestUtil (); # $r->dir_config()
-use Apache2::Log ();         # $log->info()
+use Apache::Filter ();      # $f
+use Apache::RequestRec ();  # $r
+use Apache::RequestUtil (); # $r->dir_config()
+use Apache::Log ();         # $log->info()
 use APR::Table ();          # dir_config->get() and headers_out->get()
 
-use Apache2::Const -compile => qw(OK DECLINED);
+use Apache::Const -compile => qw(OK DECLINED);
 
-use HTML::Clean ();
+use HTML::Clean;
+
+$Apache::Clean::VERSION = '2.01b';
 
 use strict;
 
-our $VERSION = '2.00_7';
-
 sub handler {
 
   my $f   = shift;
@@ -24,11 +22,13 @@ sub handler {
 
   my $log = $r->server->log;
 
+  $log->info('Using Apache::Clean to clean up ', $r->uri);
+
   # we only process HTML documents
   unless ($r->content_type =~ m!text/html!i) {
     $log->info('skipping request to ', $r->uri, ' (not an HTML document)');
 
-    return Apache2::Const::DECLINED;
+    return Apache::DECLINED;
   }
 
   my $context;
@@ -40,12 +40,17 @@ sub handler {
     # parse the configuration options
     my $level = $r->dir_config->get('CleanLevel') || 1;
 
+    $log->info("Using CleanLevel $level");
+
     my %options = map { $_ => 1 } $r->dir_config->get('CleanOption');
 
+    $log->info('Found CleanOption ', join " : ", keys %options)
+      if %options;
+
     # store the configuration
     $context = { level   => $level,
                  options => \%options,
-                 extra   => undef };
+                 extra   => '' };
 
     # output filters that alter content are responsible for removing
     # the Content-Length header, but we only need to do this once.
@@ -90,7 +95,7 @@ sub handler {
     $f->ctx($context);
   }
 
-  return Apache2::Const::OK;
+  return Apache::OK;
 }
 
 1;
@@ -99,21 +104,22 @@ __END__
 
 =head1 NAME 
 
-Apache::Clean - interface into HTML::Clean for mod_perl 2.0
+Apache::Clean - mod_perl interface into HTML::Clean
 
 =head1 SYNOPSIS
 
 httpd.conf:
 
-  PerlModule Apache::Clean
+ PerlModule Apache::Clean
 
-  Alias /clean /usr/local/apache2/htdocs
-  <Location /clean>
+ <Location /clean>
     PerlOutputFilterHandler Apache::Clean
 
-    PerlSetVar CleanOption shortertags
-    PerlAddVar CleanOption whitespace
-  </Location>
+    PerlSetVar  CleanLevel 3
+
+    PerlSetVar  CleanOption shortertags
+    PerlAddVar  CleanOption whitespace
+ </Location>  
 
 =head1 DESCRIPTION
 
@@ -123,10 +129,6 @@ bandwidth.
 Only documents with a content type of "text/html" are affected - all
 others are passed through unaltered.
 
-For more information, see
-
-  http://www.perl.com/pub/a/2003/04/17/filters.html
-
 =head1 OPTIONS
 
 Apache::Clean supports few options - all of which are based on
@@ -149,11 +151,10 @@ CleanLevel defaults to 1.
 =item CleanOption
 
 specifies the set of options which are passed to the options()
-method in HTML::Clean - see the HTML::Clean manpage for a complete
-list of options.
+method in HTML::Clean.
 
-  PerlSetVar CleanOption shortertags
-  PerlAddVar CleanOption whitespace
+  PerlAddVar CleanOption shortertags
+  PerlSetVar CleanOption whitespace
 
 CleanOption has no default.
 
@@ -168,9 +169,13 @@ platforms or environments.
 
 probably lots - this is the preliminary port to mod_perl 2.0
 
+in particular, this module does not handle conditional GET 
+requests properly.
+
 =head1 SEE ALSO
 
-perl(1), mod_perl(3), Apache(3), HTML::Clean(3)
+perl(1), mod_perl(3), Apache(3), HTML::Clean(3),
+http://perl.apache.org/docs/2.0/user/handlers/filters.html
 
 =head1 AUTHOR
 
@@ -178,7 +183,7 @@ Geoffrey Young <geoff@modperlcookbook.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005, Geoffrey Young
+Copyright (c) 2002, Geoffrey Young
 All rights reserved.
 
 This module is free software.  It may be used, redistributed
